@@ -43,7 +43,7 @@ def multifunc(data,axisref,deffunc):
             sizeout[dim] = size(data,axis=dim)
     # print(SEL)
     # print(data.shape)
-    dummydataout = deffunc(data[arraysel(data.shape,SEL)])
+    dummydataout = deffunc(data[arraysel(SEL,data.shape)])
     dimout = 0
     for dim in range(len(shape(data))):
         if (axisref[dim] == True):
@@ -83,7 +83,7 @@ def scandata(dimidx,axisref,SEL,data,deffunc,SELout,dataout):
             # print(dataout.shape)
             # print(SEL)
             # print(data.shape)
-            dataout[arraysel(dataout.shape,SELout)] = deffunc(data[arraysel(data.shape,SEL)])
+            dataout[arraysel(SELout,dataout.shape)] = deffunc(data[arraysel(SEL,data.shape)])
 
         print('axidx',axidx)
         print('SEL',SEL)
@@ -103,7 +103,7 @@ def reddim(data,indices,el = 0):
             SEL[dim] = el
         else:
             SEL[dim] = range(size(data,axis=dim))
-    return data[arraysel(shape(data),SEL)]
+    return data[arraysel(SEL,shape(data))]
 
 
 # # reduce multiple dimensions at ones
